@@ -19,8 +19,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Code:
 
@@ -48,15 +48,9 @@
     (end-of-line)
     (point)))
 
-(defvar riece-read-passwd nil)
+(autoload 'read-passwd "passwd")
+(defvar riece-read-passwd #'read-passwd)
 (defun riece-read-passwd (prompt)
-  (if (not riece-read-passwd)
-      (if (functionp 'read-passwd)
-	  (setq riece-read-passwd 'read-passwd)
-	(if (load "passwd" t)
-	    (setq riece-read-passwd 'read-passwd)
-	  (autoload 'ange-ftp-read-passwd "ange-ftp")
-	  (setq riece-read-passwd 'ange-ftp-read-passwd))))
   (funcall riece-read-passwd prompt))
 
 (if (string-match "0\\{0\\}" "")
@@ -72,6 +66,22 @@
 			  (make-list (- max min) (concat regexp "?"))))
 	       "")))
 
+(if (get 'make-local-hook 'byte-obsolete-info)
+    (defalias 'riece-make-local-hook 'ignore)
+  (defalias 'riece-make-local-hook 'make-local-hook))
+
+(autoload 'derived-mode-class "derived")
+(if (fboundp 'derived-mode-p)
+    (defalias 'riece-derived-mode-p 'derived-mode-p)
+  (defun riece-derived-mode-p (&rest modes)
+    (memq (derived-mode-class major-mode) modes)))
+
+(if (fboundp 'set-process-query-on-exit-flag)
+    (defalias 'riece-set-process-query-on-exit-flag
+      'set-process-query-on-exit-flag)
+  (defalias 'riece-set-process-query-on-exit-flag
+    'process-kill-without-query))
+
 (provide 'riece-compat)
 
 ;;; riece-compat.el ends here
