@@ -31,8 +31,6 @@
 (require 'riece-addon)
 (require 'riece-signal)
 
-(autoload 'derived-mode-class "derived")
-
 (defvar riece-channel-list-mode-map (make-sparse-keymap))
 (defvar riece-user-list-mode-map (make-sparse-keymap))
 
@@ -238,17 +236,27 @@ If optional argument SAFE is nil, overwrite previous definitions."
   (let ((files (if file
 		   (setq riece-variables-file file
 			 riece-variables-files (list file))
-		 riece-variables-files)))
+		 riece-variables-files))
+	(variables riece-saved-forms))
     (while files
       (condition-case nil
 	  (load (expand-file-name (car files)))
 	(file-error nil))
-      (setq files (cdr files)))))
+      (setq files (cdr files)))
+    (while variables
+      (if (fboundp 'custom-reevaluate-setting)
+	  (custom-reevaluate-setting (car variables))
+	(funcall (or (get (car variables) 'custom-set) 'set-default)
+		 (car variables)
+		 (eval (car (or (get (car variables) 'saved-value)
+				(get (car variables) 'standard-value))))))
+      (setq variables (cdr variables)))))
 
 (defvar print-quoted)
 (defvar print-escape-multibyte)
 (defun riece-save-variables-files ()
   "Save current settings to `riece-saved-variables-file'."
+  (message (riece-mcat "Saving %s...") riece-saved-variables-file)
   (with-temp-file riece-saved-variables-file
     (insert ";;; This file is generated automatically by " riece-version ".\n"
 	    ";;; Do not edit this file!\n\n")
@@ -258,12 +266,15 @@ If optional argument SAFE is nil, overwrite previous definitions."
 	  print-level
 	  print-length
 	  (variables riece-saved-forms))
+      (insert "(custom-set-variables\n")
       (while variables
-	(prin1 `(setq ,(car variables)
-		      ',(symbol-value (car variables)))
+	(insert " '")
+	(prin1 `(,(car variables) ',(symbol-value (car variables)))
 	       (current-buffer))
 	(insert "\n")
-	(setq variables (cdr variables)))))
+	(setq variables (cdr variables)))
+      (insert ")")))
+  (message (riece-mcat "Saving %s...done") riece-saved-variables-file)
   (setq riece-save-variables-are-dirty nil))
 
 ;;;###autoload
@@ -286,7 +297,8 @@ If optional argument CONFIRM is non-nil, ask which IRC server to connect."
 	(riece-insinuate-addon (car (car pointer)) riece-debug)
 	(setq pointer (cdr pointer))))
     (if (or confirm (null riece-server))
-	(setq riece-server (completing-read "Server: " riece-server-alist)))
+	(setq riece-server (completing-read (riece-mcat "Server: ")
+					    riece-server-alist)))
     (if (stringp riece-server)
 	(setq riece-server (riece-server-name-to-server riece-server)))
     (riece-create-buffers)
@@ -316,7 +328,7 @@ If optional argument CONFIRM is non-nil, ask which IRC server to connect."
 	  (setq pointer (cdr pointer))))
       (run-hooks 'riece-startup-hook)
       (message "%s" (substitute-command-keys
-		     "Type \\[describe-mode] for help")))))
+		     (riece-mcat "Type \\[describe-mode] for help"))))))
 
 (defun riece-exit ()
   (if riece-save-variables-are-dirty
@@ -333,8 +345,8 @@ If optional argument CONFIRM is non-nil, ask which IRC server to connect."
 	riece-channel-buffer nil
 	riece-channel-buffer-alist nil
 	riece-user-indicator nil
-	riece-long-channel-indicator "None"
-	riece-channel-list-indicator "No channel"
+	riece-long-channel-indicator (riece-mcat "None")
+	riece-channel-list-indicator (riece-mcat "No channel")
 	riece-away-indicator "-"
 	riece-operator-indicator "-"
 	riece-channel-status-indicator "-"
@@ -385,9 +397,12 @@ For a list of the generic commands type \\[riece-command-generic] ? RET.
     (setq riece-command-mode-syntax-table
 	  (copy-syntax-table (syntax-table)))
     (set-syntax-table riece-command-mode-syntax-table)
-    (mapcar
-     (lambda (c) (modify-syntax-entry c "w"))
-     "^[]{}'`"))
+    (let* ((chars "^[]{}'`")
+	   (length (length chars))
+	   (index 0))
+      (while (< index length)
+	(modify-syntax-entry (aref chars index) "w")
+	(setq index (1+ index)))))
 
   (run-hooks 'riece-command-mode-hook))
 
@@ -477,7 +492,7 @@ All normal editing commands are turned off."
 	 riece-mode-line-buffer-identification)
 	truncate-lines t
 	buffer-read-only t)
-  (make-local-hook 'riece-update-buffer-functions)
+  (riece-make-local-hook 'riece-update-buffer-functions)
   (add-hook 'riece-update-buffer-functions
 	    'riece-update-channel-list-buffer nil t)
   (use-local-map riece-channel-list-mode-map)
@@ -508,7 +523,7 @@ Instead, these commands are available:
 	buffer-read-only t)
   (if (boundp 'transient-mark-mode)
       (set (make-local-variable 'transient-mark-mode) t))
-  (make-local-hook 'riece-update-buffer-functions)
+  (riece-make-local-hook 'riece-update-buffer-functions)
   (add-hook 'riece-update-buffer-functions
 	    'riece-update-user-list-buffer nil t)
   (use-local-map riece-user-list-mode-map)
@@ -526,100 +541,10 @@ Instead, these commands are available:
 	  (funcall (nth 2 (car alist))))
 	(setq alist (cdr alist))))))
 
-(defvar reporter-prompt-for-summary-p)
-(defun riece-submit-bug-report (&optional recent-messages recent-keys)
+(defun riece-submit-bug-report ()
   "Submit via mail a bug report on Riece."
-  ;; This strange form ensures that (recent-keys) is the value before
-  ;; the bug subject string is read.
-  (interactive (list (riece-recent-messages 20) (recent-keys)))
-  (message "Querying server version...")
-  (let ((pointer riece-server-process-alist)
-	nickname)
-    (while pointer
-      (when (riece-server-process-opened (cdr (car pointer)))
-	(process-send-string (cdr (car pointer)) "VERSION\r\n")
-	(if (setq nickname
-		  (with-current-buffer (process-buffer (cdr (car pointer)))
-		    riece-real-nickname))
-	    (process-send-string
-	     (cdr (car pointer))
-	     (format "PRIVMSG %s :\1VERSION\1\r\n" nickname))))
-      (setq pointer (cdr pointer))))
-  (sit-for 3)
-  (message "Querying server version...done")
-  (require 'reporter)
-  (let ((reporter-prompt-for-summary-p t))
-    (unless riece-debug
-      (error "Please turn on riece-debug and restart Riece."))
-    (reporter-submit-bug-report
-     "liece@unixuser.org"
-     (riece-version)
-     '(riece-debug)
-     nil
-     nil
-     "This bug report will be sent to the Riece Development Team,
-not to your local site managers!!
-
-Please write in Japanese or English, because the Riece maintainers do
-not have translators to read other languages for them.
-
-Please describe as succinctly as possible:
-\t- What happened.
-\t- What you thought should have happened.
-\t- Precisely what you were doing at the time.
-
-Also include a reliable recipe for triggering the bug, as well as
-any lisp back-traces that you may have.
-\(setq stack-trace-on-error t\), or \(setq debug-on-error t\) if you
-are familiar with the debugger, to get a lisp back-trace.")
-    (delete-other-windows)
-    (save-excursion
-      (goto-char (point-max))
-      (insert
-       "\nAdd-on state:\n"
-       "------------\n"
-       (save-window-excursion
-	 (save-excursion
-	   (riece-command-list-addons)
-	   (search-forward "\n\n")
-	   (buffer-substring (point-min) (point)))))
-      (insert "Recent messages from servers:\n"
-	      "--------------------------")
-      (let ((pointer riece-server-process-alist))
-	(while pointer
-	  (insert "\n- \"" (car (car pointer)) "\", \n"
-		  (format "%S" (if (equal (car (car pointer)) "")
-				   riece-server
-				 (cdr (assoc (car (car pointer))
-					     riece-server-alist))))
-		  "\n"
-		  (if (riece-server-process-opened (cdr (car pointer)))
-		      (save-excursion
-			(set-buffer (process-buffer (cdr (car pointer))))
-			(goto-char (point-max))
-			(beginning-of-line -60)
-			(buffer-substring (point) (point-max)))
-		    "(closed server)"))
-	  (setq pointer (cdr pointer))))
-      (insert "\n\nRecent debug messages:\n"
-	      "-----------------------------------\n"
-	      (with-current-buffer riece-debug-buffer
-		(buffer-string)))
-      ;; Insert recent keystrokes.
-      (insert "\n\nRecent keystrokes:\n"
-	      "-----------------\n\n")
-      (let ((before-keys (point)))
-	(insert (key-description recent-keys))
-	(save-restriction
-	  (narrow-to-region before-keys (point))
-	  (goto-char before-keys)
-	  (while (progn (move-to-column 50) (not (eobp)))
-	    (search-forward " " nil t)
-	    (insert "\n"))))
-      ;; Insert recent minibuffer messages.
-      (insert "\n\nRecent messages (most recent first):\n"
-	      "-----------------------------------\n"
-	      recent-messages))))
+  (interactive)
+  (browse-url "https://savannah.nongnu.org/bugs/?group=riece"))
 
 (provide 'riece)
 
